import { defineEventHandler, readBody, setResponseStatus } from "h3";

import { checkIsImportedProduct } from "../../orders.post";
import { orderExists } from "../[id].get";
import Snowflake from "~/utils/snowflake";
import { database } from "~/server/utils/database";
import { prismaToWeb } from "~/server/utils/prismaToWeb";

import { createError } from "#imports";

export default defineEventHandler(async (e) => {
  const body = await readBody(e);
  const idOrder = e.context.params?.id as string;
  const idImportedProduct = new Snowflake().state;

  if (!await orderExists(BigInt(idOrder))) throw createError({ statusCode: 404 });
  if (!checkIsImportedProduct(body, false, false)) throw createError({ message: "Invalid body", statusCode: 400 });

  const rvalue = await database.importedProduct.create({
    data: {
      id: idImportedProduct,
      link: body.link,
      name: body.name,
      orderId: BigInt(idOrder),
      price: body.price,
      price_imported: body.price_imported,
    },
  });

  setResponseStatus(e, 201);

  return prismaToWeb(rvalue);
});
