import { defineEventHandler } from "h3";

import { orderExists } from "../[id].get";
import { database } from "~/server/utils/database";
import { prismaToWeb } from "~/server/utils/prismaToWeb";

import { createError } from "#imports";

export default defineEventHandler(async (e) => {
  const orderId = e.context.params?.id as string;

  if (!await orderExists(BigInt(orderId))) throw createError({ statusCode: 404 });

  const data = await database.work.findMany({
    where: {
      orderId: BigInt(orderId),
    },
    select: {
      id: true,
      fulfilled: true,
      notes: true,
      offer: true,
      orderId: true,
      price: true,
    },
  });

  if (!data) throw createError({ statusCode: 404 });

  return prismaToWeb(data);
});
