import { defineEventHandler, readBody, setResponseStatus } from "h3";
import { Decimal } from "@prisma/client/runtime/library";

import { checkIsWork } from "../../orders.post";
import { orderExists } from "../[id].get";
import Snowflake from "~/utils/snowflake";
import { database } from "~/server/utils/database";
import { prismaToWeb } from "~/server/utils/prismaToWeb";

import { createError } from "#imports";

export default defineEventHandler(async (e) => {
  const body = await readBody(e);
  const idOrder = e.context.params?.id as string;
  const idWork = new Snowflake().state;

  if (!orderExists(BigInt(idOrder))) throw createError({ statusCode: 404 });
  if (!checkIsWork(body, false, false)) throw createError({ message: "Invalid body", statusCode: 400 });

  const rvalue = await database.work.create({
    data: {
      id: BigInt(idWork),
      fulfilled: body.fulfilled,
      notes: body.notes,
      offerId: BigInt(body.offerId),
      orderId: BigInt(body.orderId),
      price: new Decimal(body.price),
    },
  });

  setResponseStatus(e, 201);

  return prismaToWeb(rvalue);
});
